@@ -19,23 +19,21 @@ import uuid
 from keystoneclient.contrib.ec2 import utils as ec2_utils
 import mock
 from oslo_db import exception as oslo_db_exception
-from oslo_serialization import jsonutils
 from six.moves import http_client
 from testtools import matchers
 
+from keystone.api import ec2tokens
 from keystone.common import provider_api
 from keystone.common import utils
-from keystone.contrib.ec2 import controllers
 from keystone.credential.providers import fernet as credential_fernet
 from keystone import exception
 from keystone.tests import unit
 from keystone.tests.unit import ksfixtures
-from keystone.tests.unit.ksfixtures import temporaryfile
 from keystone.tests.unit import test_v3
 
 
 PROVIDERS = provider_api.ProviderAPIs
-CRED_TYPE_EC2 = controllers.CRED_TYPE_EC2
+CRED_TYPE_EC2 = ec2tokens.CRED_TYPE_EC2
 
 
 class CredentialBaseTestCase(test_v3.RestfulTestCase):
@@ -117,6 +115,11 @@ class CredentialTestCase(CredentialBaseTestCase):
 
     def test_list_credentials_filtered_by_type(self):
         """Call ``GET  /credentials?type={type}``."""
+        PROVIDERS.assignment_api.create_system_grant_for_user(
+            self.user_id, self.role_id
+        )
+        token = self.get_system_scoped_token()
+
         # The type ec2 was chosen, instead of a random string,
         # because the type must be in the list of supported types
         ec2_credential = unit.new_credential_ref(user_id=uuid.uuid4().hex,
@@ -127,14 +130,14 @@ class CredentialTestCase(CredentialBaseTestCase):
             ec2_credential['id'], ec2_credential)
 
         # The type cert was chosen for the same reason as ec2
-        r = self.get('/credentials?type=cert')
+        r = self.get('/credentials?type=cert', token=token)
 
         # Testing the filter for two different types
         self.assertValidCredentialListResponse(r, ref=self.credential)
         for cred in r.result['credentials']:
             self.assertEqual('cert', cred['type'])
 
-        r_ec2 = self.get('/credentials?type=ec2')
+        r_ec2 = self.get('/credentials?type=ec2', token=token)
         self.assertThat(r_ec2.result['credentials'], matchers.HasLength(1))
         cred_ec2 = r_ec2.result['credentials'][0]
 
@@ -147,6 +150,11 @@ class CredentialTestCase(CredentialBaseTestCase):
         user1_id = uuid.uuid4().hex
         user2_id = uuid.uuid4().hex
 
+        PROVIDERS.assignment_api.create_system_grant_for_user(
+            self.user_id, self.role_id
+        )
+        token = self.get_system_scoped_token()
+
         # Creating credentials for two different users
         credential_user1_ec2 = unit.new_credential_ref(user_id=user1_id,
                                                        type=CRED_TYPE_EC2)
@@ -160,7 +168,9 @@ class CredentialTestCase(CredentialBaseTestCase):
         PROVIDERS.credential_api.create_credential(
             credential_user2_cert['id'], credential_user2_cert)
 
-        r = self.get('/credentials?user_id=%s&type=ec2' % user1_id)
+        r = self.get(
+            '/credentials?user_id=%s&type=ec2' % user1_id, token=token
+        )
         self.assertValidCredentialListResponse(r, ref=credential_user1_ec2)
         self.assertThat(r.result['credentials'], matchers.HasLength(1))
         cred = r.result['credentials'][0]
@@ -383,95 +393,6 @@ class CredentialTestCase(CredentialBaseTestCase):
         self.assertValidCredentialResponse(r, ref)
 
 
-class CredentialSelfServiceTestCase(CredentialBaseTestCase):
-    """Test self-service credential CRUD."""
-
-    def _policy_fixture(self):
-        return ksfixtures.Policy(self.tmpfilename, self.config_fixture)
-
-    def _set_policy(self, new_policy):
-        with open(self.tmpfilename, "w") as policyfile:
-            policyfile.write(jsonutils.dumps(new_policy))
-
-    def setUp(self):
-        self.tempfile = self.useFixture(temporaryfile.SecureTempFile())
-        self.tmpfilename = self.tempfile.file_name
-        super(CredentialSelfServiceTestCase, self).setUp()
-
-        # set the self-service credential policies
-        self_service_credential_policies = {
-            "identity:create_credential": "user_id:%(credential.user_id)s",
-            "identity:list_credentials": "user_id:%(user_id)s",
-            "identity:get_credential": "user_id:%(target.credential.user_id)s",
-            "identity:update_credential":
-                "user_id:%(target.credential.user_id)s",
-            "identity:delete_credential":
-                "user_id:%(target.credential.user_id)s"
-        }
-        self._set_policy(self_service_credential_policies)
-
-        # remove the 'admin' role from user and replace it with an
-        # arbitrary role
-        PROVIDERS.assignment_api.remove_role_from_user_and_project(
-            self.user_id, self.project_id, self.role_id)
-        self.arbitrary_role = unit.new_role_ref(name=uuid.uuid4().hex)
-        PROVIDERS.role_api.create_role(self.arbitrary_role['id'],
-                                       self.arbitrary_role)
-        PROVIDERS.assignment_api.add_role_to_user_and_project(
-            self.user_id, self.project_id, self.arbitrary_role['id'])
-
-        self.credential = unit.new_credential_ref(user_id=self.user['id'],
-                                                  project_id=self.project_id)
-
-        PROVIDERS.credential_api.create_credential(
-            self.credential['id'],
-            self.credential)
-
-    def test_list_credentials_filtered_by_user_id(self):
-        """Call ``GET  /credentials?user_id={user_id}``."""
-        credential = unit.new_credential_ref(user_id=uuid.uuid4().hex)
-        PROVIDERS.credential_api.create_credential(
-            credential['id'], credential
-        )
-
-        r = self.get('/credentials?user_id=%s' % self.user['id'])
-        self.assertValidCredentialListResponse(r, ref=self.credential)
-        for cred in r.result['credentials']:
-            self.assertEqual(self.user['id'], cred['user_id'])
-
-    def test_create_credential(self):
-        """Call ``POST /credentials``."""
-        ref = unit.new_credential_ref(user_id=self.user['id'])
-        r = self.post(
-            '/credentials',
-            body={'credential': ref})
-        self.assertValidCredentialResponse(r, ref)
-
-    def test_get_credential(self):
-        """Call ``GET /credentials/{credential_id}``."""
-        r = self.get(
-            '/credentials/%(credential_id)s' % {
-                'credential_id': self.credential['id']})
-        self.assertValidCredentialResponse(r, self.credential)
-
-    def test_update_credential(self):
-        """Call ``PATCH /credentials/{credential_id}``."""
-        ref = unit.new_credential_ref(user_id=self.user['id'],
-                                      project_id=self.project_id)
-        del ref['id']
-        r = self.patch(
-            '/credentials/%(credential_id)s' % {
-                'credential_id': self.credential['id']},
-            body={'credential': ref})
-        self.assertValidCredentialResponse(r, ref)
-
-    def test_delete_credential(self):
-        """Call ``DELETE /credentials/{credential_id}``."""
-        self.delete(
-            '/credentials/%(credential_id)s' % {
-                'credential_id': self.credential['id']})
-
-
 class TestCredentialTrustScoped(test_v3.RestfulTestCase):
     """Test credential with trust scoped token."""
 
